launchpad-reviewers team mailing list archive
-
launchpad-reviewers team
-
Mailing list archive
-
Message #24587
[Merge] ~cjwatson/launchpad:oci-recipe-feature-disabled-grammar into launchpad:master
Colin Watson has proposed merging ~cjwatson/launchpad:oci-recipe-feature-disabled-grammar into launchpad:master.
Commit message:
Fix grammar of OCIRecipeFeatureDisabled message
Requested reviews:
Launchpad code reviewers (launchpad-reviewers)
For more details, see:
https://code.launchpad.net/~cjwatson/launchpad/+git/launchpad/+merge/382117
--
Your team Launchpad code reviewers is requested to review the proposed merge of ~cjwatson/launchpad:oci-recipe-feature-disabled-grammar into launchpad:master.
diff --git a/lib/lp/oci/interfaces/ocirecipe.py b/lib/lp/oci/interfaces/ocirecipe.py
index ed3f9b2..25a8967 100644
--- a/lib/lp/oci/interfaces/ocirecipe.py
+++ b/lib/lp/oci/interfaces/ocirecipe.py
@@ -78,11 +78,11 @@ OCI_RECIPE_ALLOW_CREATE = 'oci.recipe.create.enabled'
@error_status(http_client.UNAUTHORIZED)
class OCIRecipeFeatureDisabled(Unauthorized):
"""Only certain users can create new LiveFS-related objects."""
def __init__(self):
super(OCIRecipeFeatureDisabled, self).__init__(
- "You do not have permission to create new OCI recipe.")
+ "You do not have permission to create new OCI recipes.")
@error_status(http_client.UNAUTHORIZED)
@@ -78,11 +78,11 @@ OCI_RECIPE_ALLOW_CREATE = 'oci.recipe.create.enabled'
class OCIRecipeFeatureDisabled(Unauthorized):
- """Only certain users can create new LiveFS-related objects."""
+ """Only certain users can create new OCI recipes."""
def __init__(self):
super(OCIRecipeFeatureDisabled, self).__init__(